@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::KENTNL::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.7.3';
+  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.7.4';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
@@ -22,6 +22,7 @@ use namespace::autoclean -also => [qw( _expand _defined_or _only_git _only_cpan
 
 
 
+
 sub _expand {
   my ( $class, $suffix, $conf ) = @_;
   ## no critic ( RequireInterpolationOfMetachars )
@@ -286,7 +287,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 1.7.3
+version 1.7.4
 
 =head1 SYNOPSIS
 
@@ -360,6 +361,18 @@ I wish to give proper respect to the people out there already implementing this
 
 See L<< the C<PluginBundle> role|Dist::Zilla::Role::PluginBundle >> for what this is for, it is a method to satisfy that role.
 
+=begin MetaPOD::JSON v1.1.0
+
+{
+    "namespace":"Dist::Zilla::PluginBundle::Author::KENTNL",
+    "interface":"class",
+    "inherits":"Moose::Object",
+    "does":"Dist::Zilla::Role::PluginBundle"
+}
+
+
+=end MetaPOD::JSON
+
 =head1 ENVIRONMENT
 
 all of these have to merely exist to constitute a "true" status.
